<?php

namespace Assetdocs\Incidentpkgs\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Incidentpkgs\Interfaces\IncidentpkgRepositoryInterface;
use Assetdocs\Incidentpkgs\Repositories\Presenter\IncidentpkgItemTransformer;

/**
 * Pubic API controller class.
 */
class IncidentpkgApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Incidentpkg\Interfaces\IncidentpkgRepositoryInterface $incidentpkg
     *
     * @return type
     */
    public function __construct(IncidentpkgRepositoryInterface $incidentpkg)
    {
        $this->middleware('api');

        $this->repository = $incidentpkg;
        parent::__construct();
    }

    /**
     * Show incidentpkg's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $incidentpkgs = $this->repository
            ->pushCriteria(new \Assetdocs\Incidentpkgs\Repositories\Criteria\IncidentpkgPublicCriteria())
            ->setPresenter('\\Assetdocs\\Incidentpkgs\\Repositories\\Presenter\\IncidentpkgListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $incidentpkgs['code'] = 2000;
        return response()->json($incidentpkgs)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show incidentpkg.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $incidentpkg = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($incidentpkg)) {
            $incidentpkg         = $this->itemPresenter($module, new IncidentpkgItemTransformer);
            $incidentpkg['code'] = 2001;
            return response()->json($incidentpkg)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
